/**************************************************************
 * Structured Markov Chains Solver       [  SMCSolver  ]      *
 * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
 * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
 * Dipartimento di Matematica "Leonida Tonelli"               *
 * Largo Pontecorvo 5                                         *
 * 56127 Pisa                                                 *
 * Italy                                                      *
 * Version 2.1 - June  2009                                   *
 **************************************************************
 *
 *  examples.h  
 *
 */

/* prototypes */
void init_examples(void);



/* globals */
int selected_es;
int examples_no; /* =9= number of possible examples 1..9 */
int is_debug;

struct  examples_str es[10];

/*********************************************/
